
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __LIBVIRT_GOBJECT_ENUMS_H__
#define __LIBVIRT_GOBJECT_ENUMS_H__

#include <libvirt-gobject/libvirt-gobject.h>

G_BEGIN_DECLS
GType gvir_domain_snapshot_delete_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_SNAPSHOT_DELETE_FLAGS (gvir_domain_snapshot_delete_flags_get_type ())
GType gvir_domain_snapshot_revert_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_SNAPSHOT_REVERT_FLAGS (gvir_domain_snapshot_revert_flags_get_type ())
GType gvir_domain_state_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_STATE (gvir_domain_state_get_type ())
GType gvir_domain_start_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_START_FLAGS (gvir_domain_start_flags_get_type ())
GType gvir_domain_delete_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_DELETE_FLAGS (gvir_domain_delete_flags_get_type ())
GType gvir_domain_xml_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_XML_FLAGS (gvir_domain_xml_flags_get_type ())
GType gvir_domain_shutdown_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_SHUTDOWN_FLAGS (gvir_domain_shutdown_flags_get_type ())
GType gvir_domain_snapshot_create_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_SNAPSHOT_CREATE_FLAGS (gvir_domain_snapshot_create_flags_get_type ())
GType gvir_domain_update_device_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_UPDATE_DEVICE_FLAGS (gvir_domain_update_device_flags_get_type ())
GType gvir_domain_reboot_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_REBOOT_FLAGS (gvir_domain_reboot_flags_get_type ())
GType gvir_domain_snapshot_list_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_DOMAIN_SNAPSHOT_LIST_FLAGS (gvir_domain_snapshot_list_flags_get_type ())
GType gvir_ip_addr_type_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_IP_ADDR_TYPE (gvir_ip_addr_type_get_type ())
GType gvir_storage_pool_state_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_STORAGE_POOL_STATE (gvir_storage_pool_state_get_type ())
GType gvir_storage_vol_type_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_STORAGE_VOL_TYPE (gvir_storage_vol_type_get_type ())
GType gvir_storage_vol_resize_flags_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_STORAGE_VOL_RESIZE_FLAGS (gvir_storage_vol_resize_flags_get_type ())
GType gvir_stream_io_condition_get_type (void) G_GNUC_CONST;
#define GVIR_TYPE_STREAM_IO_CONDITION (gvir_stream_io_condition_get_type ())
G_END_DECLS

#endif /* __LIBVIRT_GOBJECT_ENUMS_H__ */

/* Generated data ends here */

